require 'optipipe/models/mapper'
require 'optipipe/helpers/tag_helper'

module Optipipe
  class Engine < ::Rails::Engine
    isolate_namespace Optipipe

    # Add precompile paths.
    initializer "optipipe.assets.precompile" do |app|
      app.config.assets.precompile = app.config.assets.precompile.map do |precompile_setting|
        next precompile_setting unless precompile_setting.is_a?(Proc)

        if Rails::VERSION::MAJOR == 3
          lambda do |path|
            precompile_setting.call(path) &&
            !(path =~ /optipipe\/mappers\// &&
            ['.yml'].include?(File.extname(path)))
          end
        else
          lambda do |logical_path, filename|
            precompile_setting.call(logical_path, filename) &&
            !(filename.start_with?(::Rails.root.join("app/assets/optipipe/mappers").to_s) &&
            ['.yml'].include?(File.extname(logical_path)))
          end
        end
      end
      app.config.assets.precompile << 'optipipe/precompiles/*.js'
      app.config.assets.precompile << 'optipipe/precompiles/*.css'
    end

    # Add helpers
    initializer 'optipipe.action_view_helpers' do
      ActiveSupport.on_load :action_view do
        include Optipipe::TagHelper
      end
    end
  end
end
